[SCM] WebKit Debian packaging branch, debian/unstable, updated. debian/1.1.15-1-40151-g37bb677

sullivan sullivan at 268f45cc-cd09-0410-ab3c-d52691b4dbfc
Sat Sep 26 08:16:28 UTC 2009


The following commit has been merged in the debian/unstable branch:
commit 9a43a5ada59f9a60bdc93469e0ebd9525e4b39e4
Author: sullivan <sullivan at 268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Fri Dec 5 18:06:33 2003 +0000

            - fixed <rdar://problem/3491427>: REGRESSION (100-114): multi-page HTML
            content in Mail is blank when printed
    
            Darin and I figured this one out.
    
            Reviewed by Ken.
    
            * WebView.subproj/WebHTMLView.m:
            (-[WebHTMLView _setPrinting:minimumPageWidth:maximumPageWidth:adjustViewSize:]):
            Don't call setNeedsDisplay:NO when we're turning printing on, as doing so prevents
            anything from drawing in the case where this is called from
            adjustPageHeightsNew:top:bottom:limit
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@5707 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebKit/ChangeLog b/WebKit/ChangeLog
index af5c899..afaf73e 100644
--- a/WebKit/ChangeLog
+++ b/WebKit/ChangeLog
@@ -1,3 +1,18 @@
+2003-12-05  John Sullivan  <sullivan at apple.com>
+
+        - fixed <rdar://problem/3491427>: REGRESSION (100-114): multi-page HTML 
+        content in Mail is blank when printed
+
+        Darin and I figured this one out.
+
+        Reviewed by Ken.
+
+        * WebView.subproj/WebHTMLView.m:
+        (-[WebHTMLView _setPrinting:minimumPageWidth:maximumPageWidth:adjustViewSize:]):
+        Don't call setNeedsDisplay:NO when we're turning printing on, as doing so prevents
+        anything from drawing in the case where this is called from 
+        adjustPageHeightsNew:top:bottom:limit
+
 2003-12-05  Darin Adler  <darin at apple.com>
 
         Reviewed by John.
diff --git a/WebKit/WebView.subproj/WebHTMLView.m b/WebKit/WebView.subproj/WebHTMLView.m
index 2ef09e1..843dc88 100644
--- a/WebKit/WebView.subproj/WebHTMLView.m
+++ b/WebKit/WebView.subproj/WebHTMLView.m
@@ -1635,7 +1635,7 @@ static WebHTMLView *lastHitView = nil;
 {
 }
 
 // Does setNeedsDisplay:NO as a side effect. Useful for begin/endDocument.
 // pageWidth != 0 implies we will relayout to a new width
 - (void)_setPrinting:(BOOL)printing minimumPageWidth:(float)minPageWidth maximumPageWidth:(float)maxPageWidth adjustViewSize:(BOOL)adjustViewSize
 {
@@ -1658,7 +1658,10 @@ static WebHTMLView *lastHitView = nil;
         [self setNeedsToApplyStyles:YES];
         [self setNeedsLayout:YES];
         [self layoutToMinimumPageWidth:minPageWidth maximumPageWidth:maxPageWidth adjustingViewSize:adjustViewSize];
-        [self setNeedsDisplay:NO];
+        if (!printing) {
+            // Can't do this when starting printing or nested printing won't work, see 3491427.
+            [self setNeedsDisplay:NO];
+        }
     }
 }
 
@@ -1635,7 +1635,7 @@ static WebHTMLView *lastHitView = nil;
 }
 
-// Does setNeedsDisplay:NO as a side effect. Useful for begin/endDocument.
+// Does setNeedsDisplay:NO as a side effect when printing is ending.
 // pageWidth != 0 implies we will relayout to a new width
 - (void)_setPrinting:(BOOL)printing minimumPageWidth:(float)minPageWidth maximumPageWidth:(float)maxPageWidth adjustViewSize:(BOOL)adjustViewSize

-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list